==> haskell-vector-0.13.2.0-310.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector
version:              0.13.2.0
visibility:           public
id:                   vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
key:                  vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  255a3f566d76f3b4a4a295d7c3556413
exposed:              True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Strict Data.Vector.Strict.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
include-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0/include
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH
    vector-stream-0.1.0.1-F03bfhC0HhqL26lQDSs4vb

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-vector-z-benchmarks-O2
version:              0.13.2.0
package-name:         vector
lib-name:             benchmarks-O2
visibility:           public
id:                   vector-0.13.2.0-mTEhEN57zUK7rNlBzVnFY-benchmarks-O2
key:                  vector-0.13.2.0-mTEhEN57zUK7rNlBzVnFY-benchmarks-O2
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  f2514beb5edf841d395d1a8254e1bf32
exposed-modules:
    Bench.Vector.Algo.AwShCC Bench.Vector.Algo.FindIndexR
    Bench.Vector.Algo.HybCC Bench.Vector.Algo.Leaffix
    Bench.Vector.Algo.ListRank Bench.Vector.Algo.MutableSet
    Bench.Vector.Algo.NextPermutation Bench.Vector.Algo.Quickhull
    Bench.Vector.Algo.Rootfix Bench.Vector.Algo.Spectral
    Bench.Vector.Algo.Tridiag Bench.Vector.Tasty
    Bench.Vector.TestData.Graph Bench.Vector.TestData.ParenTree

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-mTEhEN57zUK7rNlBzVnFY-benchmarks-O2
depends:
    base-4.17.2.1 random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    tasty-1.5.2-BKpN9d8J2hIHwcKpwM8zsO
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-0.13.2.0-333-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector
version:              0.13.2.0
visibility:           public
id:                   vector-0.13.2.0-I8adDlSe4OQ1B6WgUZcyEg
key:                  vector-0.13.2.0-I8adDlSe4OQ1B6WgUZcyEg
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  a1bdddc29e38efa4177e483d8da09a2e
exposed:              True
exposed-modules:
    Data.Vector Data.Vector.Fusion.Bundle
    Data.Vector.Fusion.Bundle.Monadic Data.Vector.Fusion.Bundle.Size
    Data.Vector.Fusion.Stream.Monadic Data.Vector.Fusion.Util
    Data.Vector.Generic Data.Vector.Generic.Base
    Data.Vector.Generic.Mutable Data.Vector.Generic.Mutable.Base
    Data.Vector.Generic.New Data.Vector.Internal.Check
    Data.Vector.Mutable Data.Vector.Primitive
    Data.Vector.Primitive.Mutable Data.Vector.Storable
    Data.Vector.Storable.Internal Data.Vector.Storable.Mutable
    Data.Vector.Strict Data.Vector.Strict.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-I8adDlSe4OQ1B6WgUZcyEg
include-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0/include

depends:
    base-4.18.3.0 deepseq-1.4.8.1
    primitive-0.9.1.0-AElAOg7RWPrK8TD1mt4mft
    vector-stream-0.1.0.1-7qX9oQxWHCz9yDWW5CqJnq

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-vector-z-benchmarks-O2
version:              0.13.2.0
package-name:         vector
lib-name:             benchmarks-O2
visibility:           public
id:                   vector-0.13.2.0-EPy8EDcl6KoHwewXVeLJN7-benchmarks-O2
key:                  vector-0.13.2.0-EPy8EDcl6KoHwewXVeLJN7-benchmarks-O2
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012,
        Alexey Kuleshevich 2020-2022,
        Aleksey Khudyakov 2020-2022,
        Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Arrays
description:
    .
    An efficient implementation of @Int@-indexed arrays (both mutable
    and immutable), with a powerful loop optimisation framework .
    .
    It is structured as follows:
    .
    ["Data.Vector"] Boxed vectors of arbitrary types.
    .
    ["Data.Vector.Unboxed"] Unboxed vectors with an adaptive
    representation based on data type families.
    .
    ["Data.Vector.Storable"] Unboxed vectors of '\''Storable'\'' types.
    .
    ["Data.Vector.Primitive"] Unboxed vectors of primitive types as
    defined by the @primitive@ package. "Data.Vector.Unboxed" is more
    flexible at no performance cost.
    .
    ["Data.Vector.Generic"] Generic interface to the vector types.
    .
    There is also a (draft) tutorial on common uses of vector.
    .
    * <http://haskell.org/haskellwiki/Numeric_Haskell:_A_Vector_Tutorial>

category:             Data, Data Structures
abi:                  792a094f3a1cd382889ab9297e95a859
exposed-modules:
    Bench.Vector.Algo.AwShCC Bench.Vector.Algo.FindIndexR
    Bench.Vector.Algo.HybCC Bench.Vector.Algo.Leaffix
    Bench.Vector.Algo.ListRank Bench.Vector.Algo.MutableSet
    Bench.Vector.Algo.NextPermutation Bench.Vector.Algo.Quickhull
    Bench.Vector.Algo.Rootfix Bench.Vector.Algo.Spectral
    Bench.Vector.Algo.Tridiag Bench.Vector.Tasty
    Bench.Vector.TestData.Graph Bench.Vector.TestData.ParenTree

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/vector-0.13.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector
hs-libraries:         HSvector-0.13.2.0-EPy8EDcl6KoHwewXVeLJN7-benchmarks-O2
depends:
    base-4.18.3.0 random-1.2.1.3-FQDOWOOVQ4iCxkTbz7wiP5
    tasty-1.5.2-DYWdVUlVmZ2GEsYE1QJgVb
    vector-0.13.2.0-I8adDlSe4OQ1B6WgUZcyEg

haddock-interfaces:   /usr/share/doc/haskell-vector/html/vector.haddock
haddock-html:         /usr/share/doc/haskell-vector/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
